package gregapi.load;

import static gregapi.data.CS.*;
import gregapi.data.CS.ArmorsGT;
import gregapi.data.*;
import gregapi.oredict.OreDictItemData;
import gregapi.oredict.OreDictManager;
import gregapi.util.OM;
import gregapi.util.UT;
import net.minecraft.init.Items;

/**
 * @author Gregorius Techneticies
 * 
 * Loads the ItemList (IL.java) for most Items (everything except the GT ones).
 * This happens during the InitPhase, or if GregTech is installed within the PreInitPhase, since GregTech loads after all the Mods mentioned here, unlike the API.
 */
public class LoaderItemList implements Runnable {
	@Override public String toString() {return "Item List Loader";}
	
	@Override
	public void run() {
		IL.Bottle_Empty							.set(UT.Stacks.make(Items.glass_bottle, 1, 0), OP.bottle.dat(MT.Empty));
		OP.bottle.mContainerItem =					 UT.Stacks.make(Items.glass_bottle, 1, 0);
		
		IL.Dye_Bonemeal							.set(UT.Stacks.make(Items.dye, 1, 15));
		IL.Dye_SquidInk							.set(UT.Stacks.make(Items.dye, 1, 0));
		IL.Dye_Cactus							.set(UT.Stacks.make(Items.dye, 1, 2));
		IL.Dye_Cocoa							.set(UT.Stacks.make(Items.dye, 1, 3));
		
		IL.Food_Bread							.set(UT.Stacks.make(Items.bread, 1, 0));
		IL.Food_Carrot							.set(UT.Stacks.make(Items.carrot, 1, 0));
		IL.Food_Potato							.set(UT.Stacks.make(Items.potato, 1, 0));
		IL.Food_Potato_Baked					.set(UT.Stacks.make(Items.baked_potato, 1, 0));
		IL.Food_Potato_Poisonous				.set(UT.Stacks.make(Items.poisonous_potato, 1, 0));
		
		IL.TE_Cinnabar							.set(UT.Stacks.make(MD.TE_FOUNDATION, "material"						, 1,  20), new OreDictItemData(MT.OREMATS.Cinnabar, U));
		IL.TE_Slag								.set(UT.Stacks.make(MD.TE, "material"									, 1, 514));
		IL.TE_Slag_Rich							.set(UT.Stacks.make(MD.TE, "material"									, 1, 515));
		IL.TE_Phyto_Gro							.set(UT.Stacks.make(MD.TE, "material"									, 1, 516), null, "itemFertilizer");
		IL.TE_Phyto_Gro_Rich					.set(UT.Stacks.make(MD.TE, "material"									, 1, 517), null, "itemFertilizer");
		IL.TE_Rockwool							.set(UT.Stacks.make(MD.TE, "Rockwool"									, 1,   0));
		
		IL.RC_ShuntingWire						.set(UT.Stacks.make(MD.RC, "machine.delta"								, 1, 0));
		IL.RC_ShuntingWireFrame					.set(UT.Stacks.make(MD.RC, "frame"										, 1, 0));
		IL.RC_Post_Metal						.set(UT.Stacks.make(MD.RC, "post"										, 1, 2));
		IL.RC_Concrete							.set(UT.Stacks.make(MD.RC, "cube"										, 1, 1), new OreDictItemData(MT.Stone, 5*U/8));
		IL.RC_Crushed_Obsidian					.set(UT.Stacks.make(MD.RC, "cube"										, 1, 4), new OreDictItemData(MT.Obsidian, U*8));
		IL.RC_Stone_Abyssal						.set(UT.Stacks.make(MD.RC, "cube"										, 1, 6), OP.stone.dat(MT.Basalt));
		IL.RC_Stone_Quarried					.set(UT.Stacks.make(MD.RC, "cube"										, 1, 7), OP.stone.dat(MT.Marble));
		IL.RC_Creosote_Wood						.set(UT.Stacks.make(MD.RC, "cube"										, 1, 8), new OreDictItemData(MT.Wood, U*8));
		IL.RC_Rail_Standard						.set(UT.Stacks.make(MD.RC, "part.rail"									, 1, 0));
		IL.RC_Rail_Adv							.set(UT.Stacks.make(MD.RC, "part.rail"									, 1, 1));
		IL.RC_Rail_Wooden						.set(UT.Stacks.make(MD.RC, "part.rail"									, 1, 2));
		IL.RC_Rail_HS							.set(UT.Stacks.make(MD.RC, "part.rail"									, 1, 3));
		IL.RC_Rail_Reinforced					.set(UT.Stacks.make(MD.RC, "part.rail"									, 1, 4));
		IL.RC_Rail_Electric						.set(UT.Stacks.make(MD.RC, "part.rail"									, 1, 5));
		IL.RC_Tie_Wood							.set(UT.Stacks.make(MD.RC, "part.tie"									, 1, 0), new OreDictItemData(MT.Wood, 3*U/2));
		IL.RC_Tie_Stone							.set(UT.Stacks.make(MD.RC, "part.tie"									, 1, 1), new OreDictItemData(MT.Stone, 3*U/2));
		IL.RC_Bed_Wood							.set(UT.Stacks.make(MD.RC, "part.railbed"								, 1, 0), new OreDictItemData(MT.Wood, U*6));
		IL.RC_Bed_Stone							.set(UT.Stacks.make(MD.RC, "part.railbed"								, 1, 1), new OreDictItemData(MT.Stone, U*6));
		IL.RC_Rebar								.set(UT.Stacks.make(MD.RC, "part.rebar"									, 1, 0));
		
		IL.RC_Crowbar_Iron						.set(UT.Stacks.make(MD.RC, "tool.crowbar"								, 1, 0), new OreDictItemData(MT.Fe, U*3));
		IL.RC_Crowbar_Steel						.set(UT.Stacks.make(MD.RC, "tool.crowbar.reinforced"					, 1, 0), new OreDictItemData(MT.Steel, U*3));
		IL.RC_Crowbar_Thaumium					.set(UT.Stacks.make(MD.RC, "tool.crowbar.magic"							, 1, 0), new OreDictItemData(MT.Thaumium, U*3));
		IL.RC_Crowbar_Voidmetal					.set(UT.Stacks.make(MD.RC, "tool.crowbar.void"							, 1, 0), new OreDictItemData(MT.VoidMetal, U*3));
		
		IL.Tool_Sword_Steel						.set(UT.Stacks.make(MD.RC, "tool.steel.sword"							, 1, 0));
		IL.Tool_Pickaxe_Steel					.set(UT.Stacks.make(MD.RC, "tool.steel.pickaxe"							, 1, 0));
		IL.Tool_Shovel_Steel					.set(UT.Stacks.make(MD.RC, "tool.steel.shovel"							, 1, 0));
		IL.Tool_Axe_Steel						.set(UT.Stacks.make(MD.RC, "tool.steel.axe"								, 1, 0));
		IL.Tool_Hoe_Steel						.set(UT.Stacks.make(MD.RC, "tool.steel.hoe"								, 1, 0));
		
		IL.RC_Creosote_Bottle					.set(UT.Stacks.make(MD.RC, "fluid.creosote.bottle"						, 1, 0), null, "bottleCreosote", "container1000creosote");
		IL.RC_Creosote_Bucket					.set(UT.Stacks.make(MD.RC, "fluid.creosote.bucket"						, 1, 0), null, "bucketCreosote");
		IL.RC_Creosote_Can						.set(UT.Stacks.make(MD.RC, "fluid.creosote.can"							, 1, 0), null, "container1000creosote");
		IL.RC_Creosote_Capsule					.set(UT.Stacks.make(MD.RC, "fluid.creosote.wax"							, 1, 0), null, "container1000creosote");
		IL.RC_Creosote_RefractoryCapsule		.set(UT.Stacks.make(MD.RC, "fluid.creosote.refactory"					, 1, 0), null, "container1000creosote");
		
		if (IL.RC_Creosote_Bottle.getItem() != null) IL.RC_Creosote_Bottle.getItem().setContainerItem(Items.glass_bottle);
		
		IL.IE_Creosote_Bottle					.set(UT.Stacks.make(MD.IE, "fluidContainers"							, 1, 0), null, "bottleCreosote", "container1000creosote");
		IL.IE_Creosote_Bucket					.set(UT.Stacks.make(MD.IE, "fluidContainers"							, 1, 1), null, "bucketCreosote");
		IL.IE_Hammer							.set(UT.Stacks.make(MD.IE, "tool"										, 1, 0), new OreDictItemData(MT.TECH.AnyIron, 2*U, MT.TECH.AnyWood, U));
		
		IL.TC_Nugget_Beef						.set(UT.Stacks.make(MD.TC, "ItemNuggetBeef"								, 1, 0), new OreDictItemData(MT.MeatCooked, U/9));
		IL.TC_Nugget_Chicken					.set(UT.Stacks.make(MD.TC, "ItemNuggetChicken"							, 1, 0), new OreDictItemData(MT.MeatCooked, U/9));
		IL.TC_Nugget_Fish						.set(UT.Stacks.make(MD.TC, "ItemNuggetFish"								, 1, 0), new OreDictItemData(MT.FishCooked, U/9));
		IL.TC_Nugget_Pork						.set(UT.Stacks.make(MD.TC, "ItemNuggetPork"								, 1, 0), new OreDictItemData(MT.MeatCooked, U/9));
		IL.TC_Triple_Meat_Treat					.set(UT.Stacks.make(MD.TC, "TripleMeatTreat"							, 1, 0), new OreDictItemData(MT.MeatCooked, U/3));
		IL.TC_Greatwood_Log						.set(UT.Stacks.make(MD.TC, "blockMagicalLog"							, 1, 0), null, "logWood");
		IL.TC_Silverwood_Log					.set(UT.Stacks.make(MD.TC, "blockMagicalLog"							, 1, 1), null, "logWood");
		IL.TC_Greatwood_Planks					.set(UT.Stacks.make(MD.TC, "blockWoodenDevice"							, 1, 6), null, "plankWood");
		IL.TC_Silverwood_Planks					.set(UT.Stacks.make(MD.TC, "blockWoodenDevice"							, 1, 7), null, "plankWood");
		IL.TC_Shimmerleaf						.set(UT.Stacks.make(MD.TC, "blockCustomPlant"							, 1, 2), new OreDictItemData(MT.Hg, U), "flowerShimmerleaf");
		IL.TC_Cinderpearl						.set(UT.Stacks.make(MD.TC, "blockCustomPlant"							, 1, 3), new OreDictItemData(MT.Blaze, U), "flowerCinderpearl");
		IL.TC_Vishroom							.set(UT.Stacks.make(MD.TC, "blockCustomPlant"							, 1, 5));
		
		IL.TF_LiveRoot							.set(UT.Stacks.make(MD.TF, "item.liveRoot"								, 1, 0), new OreDictItemData(MT.LiveRoot, U));
		IL.TF_Vial_FieryBlood					.set(UT.Stacks.make(MD.TF, "item.fieryBlood"							, 1, 0));
		IL.TF_Vial_FieryTears					.set(UT.Stacks.make(MD.TF, "item.fieryTears"							, 1, 0));
		IL.TF_Hydrachop_Raw						.set(UT.Stacks.make(MD.TF, "item.hydraChop"								, 1, 0), new OreDictItemData(MT.MeatRaw				, U*8, MT.Bone, U*2), "listAllhydraraw");
		IL.TF_Meef_Raw							.set(UT.Stacks.make(MD.TF, "item.meefRaw"								, 1, 0), new OreDictItemData(MT.MeatRaw				, U*2, MT.Bone, U/9), "listAllbeefraw");
		IL.TF_Meef_Cooked						.set(UT.Stacks.make(MD.TF, "item.meefSteak"								, 1, 0), new OreDictItemData(MT.MeatCooked			, U*2, MT.Bone, U/9), "listAllbeefcooked");
		IL.TF_Venison_Raw						.set(UT.Stacks.make(MD.TF, "item.venisonRaw"							, 1, 0), new OreDictItemData(MT.MeatRaw				, U*2, MT.Bone, U/9), "foodVenisonraw");
		IL.TF_Venison_Cooked					.set(UT.Stacks.make(MD.TF, "item.venisonCooked"							, 1, 0), new OreDictItemData(MT.MeatCooked			, U*2, MT.Bone, U/9), "foodVenisoncooked");
		IL.TF_Mushgloom							.set(UT.Stacks.make(MD.TF, "tile.TFPlant"								, 1, 9), new OreDictItemData(MT.TECH.AnyGlowstone	, U/4), "listAllmushroom");
		
		if (IL.TF_Vial_FieryBlood.getItem() != null) IL.TF_Vial_FieryBlood.getItem().setContainerItem(Items.glass_bottle);
		if (IL.TF_Vial_FieryTears.getItem() != null) IL.TF_Vial_FieryTears.getItem().setContainerItem(Items.glass_bottle);
		
		IL.MoCr_Crab_Raw						.set(UT.Stacks.make(MD.MoCr, "crabraw"									, 1, 0), new OreDictItemData(MT.FishRaw		, 3*U/2), "foodCrabraw");
		IL.MoCr_Crab_Cooked						.set(UT.Stacks.make(MD.MoCr, "crabcooked"								, 1, 0), new OreDictItemData(MT.FishCooked	, 3*U/2), "foodCrabcooked");
		IL.MoCr_Turkey_Raw						.set(UT.Stacks.make(MD.MoCr, "turkeyraw"								, 1, 0), new OreDictItemData(MT.MeatRaw		, U*3, MT.Bone, U/4), "foodTurkeyraw");
		IL.MoCr_Turkey_Cooked					.set(UT.Stacks.make(MD.MoCr, "turkeycooked"								, 1, 0), new OreDictItemData(MT.MeatCooked	, U*3, MT.Bone, U/4), "foodTurkeycooked");
		IL.MoCr_Rat_Raw							.set(UT.Stacks.make(MD.MoCr, "ratraw"									, 1, 0), new OreDictItemData(MT.MeatRaw		, U*1, MT.Bone, U/9), "foodRatraw");
		IL.MoCr_Rat_Cooked						.set(UT.Stacks.make(MD.MoCr, "ratcooked"								, 1, 0), new OreDictItemData(MT.MeatCooked	, U*1, MT.Bone, U/9), "foodRatcooked");
		IL.MoCr_Ostrich_Raw						.set(UT.Stacks.make(MD.MoCr, "ostrichraw"								, 1, 0), new OreDictItemData(MT.MeatRaw		, U*2, MT.Bone, U/4), "foodOstrichraw");
		IL.MoCr_Ostrich_Cooked					.set(UT.Stacks.make(MD.MoCr, "ostrichcooked"							, 1, 0), new OreDictItemData(MT.MeatCooked	, U*2, MT.Bone, U/4), "foodOstrichcooked");
		IL.MoCr_Turtle_Raw						.set(UT.Stacks.make(MD.MoCr, "turtleraw"								, 1, 0), new OreDictItemData(MT.MeatRaw		, U*2, MT.Bone, U/9), "foodTurtleraw");
		
		IL.MaCu_Dye_White						.set(UT.Stacks.make(MD.MaCu, "materials"								, 1,27), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_White]);
		IL.MaCu_Dye_Blue						.set(UT.Stacks.make(MD.MaCu, "materials"								, 1,28), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Blue]);
		IL.MaCu_Dye_Green						.set(UT.Stacks.make(MD.MaCu, "materials"								, 1,29), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Green]);
		IL.MaCu_Dye_Yellow						.set(UT.Stacks.make(MD.MaCu, "materials"								, 1,30), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Yellow]);
		IL.MaCu_Dye_Red							.set(UT.Stacks.make(MD.MaCu, "materials"								, 1,31), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Red]);
		IL.MaCu_Dye_Brown						.set(UT.Stacks.make(MD.MaCu, "materials"								, 1,32), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Brown]);
		IL.MaCu_Bait_Worm						.set(UT.Stacks.make(MD.MaCu, "bait"										, 1, 0));
		IL.MaCu_Bait_Ant						.set(UT.Stacks.make(MD.MaCu, "bait"										, 1, 1));
		IL.MaCu_Bait_Maggot						.set(UT.Stacks.make(MD.MaCu, "bait"										, 1, 2));
		IL.MaCu_Bait_Grasshopper				.set(UT.Stacks.make(MD.MaCu, "bait"										, 1, 3));
		IL.MaCu_Bait_Bee						.set(UT.Stacks.make(MD.MaCu, "bait"										, 1, 4));
		
		IL.ENVM_Spoiled_Milk_Bucket				.set(UT.Stacks.make(MD.ENVM, "spoiledMilk"								, 1, 0));
		IL.ENVM_Rotten_Food						.set(UT.Stacks.make(MD.ENVM, "rottenFood"								, 1, 0), null, "foodRotten");
		IL.ENVM_Bottle_Water_Cold				.set(UT.Stacks.make(MD.ENVM, "coldWaterBottle"							, 1, 0));
		IL.ENVM_Bottle_Water_Dirty				.set(UT.Stacks.make(MD.ENVM, "badWaterBottle"							, 1, 0));
		IL.ENVM_Bottle_Water_Salty				.set(UT.Stacks.make(MD.ENVM, "saltWaterBottle"							, 1, 0));
		
		IL.EtFu_Rabbit_Foot						.set(UT.Stacks.make(MD.EtFu, "rabbit_foot"								, 1, 0));
		IL.EtFu_Dragon_Breath					.set(UT.Stacks.make(MD.EtFu, "dragon_breath"							, 1, 0));
		IL.EtFu_Path							.set(UT.Stacks.make(MD.EtFu, "grass_path"								, 1, 0));
		
		IL.EBXL_Cactus_Paste					.set(UT.Stacks.make(MD.EBXL, "extrabiomes.paste"						, 1, 0));
		IL.EBXL_Dye_Black						.set(UT.Stacks.make(MD.EBXL, "extrabiomes.dye"							, 1, 0), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Black]);
		IL.EBXL_Dye_Blue						.set(UT.Stacks.make(MD.EBXL, "extrabiomes.dye"							, 1, 1), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Blue]);
		IL.EBXL_Dye_Brown						.set(UT.Stacks.make(MD.EBXL, "extrabiomes.dye"							, 1, 2), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Brown]);
		IL.EBXL_Dye_White						.set(UT.Stacks.make(MD.EBXL, "extrabiomes.dye"							, 1, 3), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_White]);
		
		IL.BoP_Mudbrick							.set(UT.Stacks.make(MD.BoP, "misc"										, 1, 0));
		IL.BoP_Ashes							.set(UT.Stacks.make(MD.BoP, "misc"										, 1, 1), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Gray]);
		IL.BoP_Comb								.set(UT.Stacks.make(MD.BoP, "misc"										, 1, 2), null, "beeComb", "materialWaxcomb");
		IL.BoP_Flesh							.set(UT.Stacks.make(MD.BoP, "misc"										, 1, 3), new OreDictItemData(MT.MeatRaw, U));
		IL.BoP_Celestial						.set(UT.Stacks.make(MD.BoP, "misc"										, 1, 4));
		IL.BoP_Dye_Blue							.set(UT.Stacks.make(MD.BoP, "misc"										, 1, 5), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Blue]);
		IL.BoP_Dye_Brown						.set(UT.Stacks.make(MD.BoP, "misc"										, 1, 6), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Brown]);
		IL.BoP_Dye_Green						.set(UT.Stacks.make(MD.BoP, "misc"										, 1, 7), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Green]);
		IL.BoP_Dye_White						.set(UT.Stacks.make(MD.BoP, "misc"										, 1, 8), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_White]);
		IL.BoP_Dye_Black						.set(UT.Stacks.make(MD.BoP, "misc"										, 1, 9), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Black]);
		IL.BoP_GhastlySoul						.set(UT.Stacks.make(MD.BoP, "misc"										, 1,10));
		IL.BoP_PixieDust						.set(UT.Stacks.make(MD.BoP, "misc"										, 1,11));
		IL.BoP_Ichor							.set(UT.Stacks.make(MD.BoP, "misc"										, 1,12));
		IL.BoP_Pinecone							.set(UT.Stacks.make(MD.BoP, "misc"										, 1,13));
		
		IL.BoP_Berry							.set(UT.Stacks.make(MD.BoP, "food"										, 1, 0), null, "cropBerry");
		IL.BoP_ShroomPowder						.set(UT.Stacks.make(MD.BoP, "food"										, 1, 1));
		IL.BoP_WildCarrots						.set(UT.Stacks.make(MD.BoP, "food"										, 1, 2), null, "cropWildcarrots");
		IL.BoP_Peach							.set(UT.Stacks.make(MD.BoP, "food"										, 1, 3), null, "cropPeach");
		IL.BoP_Persimmon						.set(UT.Stacks.make(MD.BoP, "food"										, 1, 8), null, "cropPersimmon");
		IL.BoP_HoneyComb						.set(UT.Stacks.make(MD.BoP, "food"										, 1, 9), null, "beeComb", "materialHoneycomb", "foodFilledhoneycomb");
		IL.BoP_Ambrosia							.set(UT.Stacks.make(MD.BoP, "food"										, 1,10), null, "foodAmbrosia");
		IL.BoP_Turnip							.set(UT.Stacks.make(MD.BoP, "food"										, 1,11), null, "cropTurnip");
		IL.BoP_Pear								.set(UT.Stacks.make(MD.BoP, "food"										, 1,12), null, "cropPear");
		
		IL.BoP_Jar_Empty						.set(UT.Stacks.make(MD.BoP, "jarEmpty"									, 1, 0), new OreDictItemData(MT.Glass, 7*U/3));
		IL.BoP_Jar_Honey						.set(UT.Stacks.make(MD.BoP, "jarFilled"									, 1, 0), new OreDictItemData(MT.Glass, 7*U/3), "foodHoneydrop");
		IL.BoP_Jar_Poison						.set(UT.Stacks.make(MD.BoP, "jarFilled"									, 1, 1), new OreDictItemData(MT.Glass, 7*U/3));
		IL.BoP_Jar_Pixie						.set(UT.Stacks.make(MD.BoP, "jarFilled"									, 1, 2), new OreDictItemData(MT.Glass, 7*U/3));
		
		if (IL.BoP_Jar_Honey.getItem() != null && IL.BoP_Jar_Empty.getItem() != null) IL.BoP_Jar_Honey.getItem().setContainerItem(IL.BoP_Jar_Empty.getItem());
		
		IL.RoC_Comb_Slippery					.set(UT.Stacks.make(MD.RoC, "rotarycraft_item_modinterface"				, 1, 0), null, "beeComb");
		IL.RoC_Propolis_Slippery				.set(UT.Stacks.make(MD.RoC, "rotarycraft_item_modinterface"				, 1, 1), null, "listAllpropolis");
		
		IL.JABBA_Dolly							.set(UT.Stacks.make(MD.JABBA, "mover"									, 1, 0));
		IL.JABBA_Dolly_Diamond					.set(UT.Stacks.make(MD.JABBA, "moverDiamond"							, 1, 0));
		
		IL.GC_Torch_Glowstone					.set(UT.Stacks.make(MD.GC, "tile.glowstoneTorch"						, 1, 0), new OreDictItemData(MT.TECH.AnyGlowstone, U/4, MT.TECH.AnyWood, U/4));
		
		IL.MFR_Fertilizer						.set(UT.Stacks.make(MD.MFR, "fertilizer"								, 1, 0), null, "itemFertilizer", DYE_OREDICTS_MIXABLE[DYE_INDEX_Brown]);
		
		IL.AA_Fertilizer						.set(UT.Stacks.make(MD.AA, "itemFertilizer"								, 1, 0), null, "itemFertilizer");
		IL.AA_Dye_Black							.set(UT.Stacks.make(MD.AA, "itemMisc"									, 1,17), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Black]);
		
		IL.FR_Planks_Fireproof					.set(UT.Stacks.make(MD.FR, "planksFireproof"							, 1, 0));
		IL.FR_Planks							.set(UT.Stacks.make(MD.FR, "planks"										, 1, 0));
		IL.FR_Slabs_Fireproof					.set(UT.Stacks.make(MD.FR, "slabsFireproof"								, 1, 0));
		IL.FR_Slabs								.set(UT.Stacks.make(MD.FR, "slabs"										, 1, 0));
		IL.FR_Logs_Fireproof					.set(UT.Stacks.make(MD.FR, "logsFireproof"								, 1, 0));
		IL.FR_Logs								.set(UT.Stacks.make(MD.FR, "logs"										, 1, 0));
		IL.FR_Phosphor							.set(UT.Stacks.make(MD.FR, "phosphor"									, 1, 0), new OreDictItemData(MT.P, U));
		IL.FR_Royal_Jelly						.set(UT.Stacks.make(MD.FR, "royalJelly"									, 1, 0));
		IL.FR_Propolis							.set(UT.Stacks.make(MD.FR, "propolis"									, 1, 0), null, "listAllpropolis");
		IL.FR_Propolis_Sticky					.set(UT.Stacks.make(MD.FR, "propolis"									, 1, 1), null, "listAllpropolis");
		IL.FR_Propolis_Pulsating				.set(UT.Stacks.make(MD.FR, "propolis"									, 1, 2), null, "listAllpropolis");
		IL.FR_Propolis_Silky					.set(UT.Stacks.make(MD.FR, "propolis"									, 1, 3), null, "listAllpropolis");
		IL.BINNIE_Propolis_Water				.set(UT.Stacks.make(MD.BINNIE_BEE, "propolis"							, 1, 0), null, "listAllpropolis");
		IL.BINNIE_Propolis_Oil					.set(UT.Stacks.make(MD.BINNIE_BEE, "propolis"							, 1, 1), null, "listAllpropolis");
		IL.BINNIE_Propolis_Petroleum			.set(UT.Stacks.make(MD.BINNIE_BEE, "propolis"							, 1, 2), null, "listAllpropolis");
		IL.BINNIE_Propolis_Milk					.set(UT.Stacks.make(MD.BINNIE_BEE, "propolis"							, 1, 3), null, "listAllpropolis");
		IL.BINNIE_Propolis_Fruit				.set(UT.Stacks.make(MD.BINNIE_BEE, "propolis"							, 1, 4), null, "listAllpropolis");
		IL.BINNIE_Propolis_Seed					.set(UT.Stacks.make(MD.BINNIE_BEE, "propolis"							, 1, 5), null, "listAllpropolis");
		IL.BINNIE_Propolis_Alcohol				.set(UT.Stacks.make(MD.BINNIE_BEE, "propolis"							, 1, 6), null, "listAllpropolis");
		IL.BINNIE_Propolis_Creosote				.set(UT.Stacks.make(MD.BINNIE_BEE, "propolis"							, 1, 7), null, "listAllpropolis");
		IL.BINNIE_Propolis_Glacial				.set(UT.Stacks.make(MD.BINNIE_BEE, "propolis"							, 1, 8), null, "listAllpropolis");
		IL.BINNIE_Propolis_Peat					.set(UT.Stacks.make(MD.BINNIE_BEE, "propolis"							, 1, 9), null, "listAllpropolis");
		IL.FR_Comb_Honey						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1, 0), null, "beeComb", "materialHoneycomb", "foodFilledhoneycomb");
		IL.FR_Comb_Cocoa						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1, 1), null, "beeComb");
		IL.FR_Comb_Simmering					.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1, 2), null, "beeComb");
		IL.FR_Comb_Stringy						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1, 3), null, "beeComb");
		IL.FR_Comb_Frozen						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1, 4), null, "beeComb");
		IL.FR_Comb_Dripping						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1, 5), null, "beeComb");
		IL.FR_Comb_Silky						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1, 6), null, "beeComb");
		IL.FR_Comb_Parched						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1, 7), null, "beeComb");
		IL.FR_Comb_Mysterious					.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1, 8), null, "beeComb");
		IL.FR_Comb_Irradiated					.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1, 9), null, "beeComb");
		IL.FR_Comb_Powdery						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1,10), null, "beeComb");
		IL.FR_Comb_Reddened						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1,11), null, "beeComb");
		IL.FR_Comb_Darkened						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1,12), null, "beeComb");
		IL.FR_Comb_Omega						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1,13), null, "beeComb");
		IL.FR_Comb_Wheaten						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1,14), null, "beeComb");
		IL.FR_Comb_Mossy						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1,15), null, "beeComb");
		IL.FR_Comb_Mellow						.set(UT.Stacks.make(MD.FR, "beeCombs"									, 1,16), null, "beeComb");
		IL.BINNIE_Comb_Barren					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1, 0), null, "beeComb");
		IL.BINNIE_Comb_Rotten					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1, 1), null, "beeComb");
		IL.BINNIE_Comb_Bone						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1, 2), null, "beeComb");
		IL.BINNIE_Comb_Oil						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1, 3), null, "beeComb");
		IL.BINNIE_Comb_Fossil					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1, 4), null, "beeComb");
		IL.BINNIE_Comb_Petroleum				.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1, 5), null, "beeComb");
		IL.BINNIE_Comb_Damp						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1, 6), null, "beeComb");
		IL.BINNIE_Comb_Milk						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1, 7), null, "beeComb");
		IL.BINNIE_Comb_Fruit					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1, 8), null, "beeComb");
		IL.BINNIE_Comb_Seed						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1, 9), null, "beeComb");
		IL.BINNIE_Comb_Alcohol					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,10), null, "beeComb");
		IL.BINNIE_Comb_Rock						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,11), null, "beeComb");
		IL.BINNIE_Comb_Energetic				.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,12), null, "beeComb");
		IL.BINNIE_Comb_Amber					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,13), null, "beeComb");
		IL.BINNIE_Comb_Static					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,14), null, "beeComb");
		IL.BINNIE_Comb_Iron						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,15), null, "beeComb");
		IL.BINNIE_Comb_Gold						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,16), null, "beeComb");
		IL.BINNIE_Comb_Copper					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,17), null, "beeComb");
		IL.BINNIE_Comb_Tin						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,18), null, "beeComb");
		IL.BINNIE_Comb_Silver					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,19), null, "beeComb");
		IL.BINNIE_Comb_Bronze					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,20), null, "beeComb");
		IL.BINNIE_Comb_Uranium					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,21), null, "beeComb");
		IL.BINNIE_Comb_Clay						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,22), null, "beeComb");
		IL.BINNIE_Comb_Old						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,23), null, "beeComb");
		IL.BINNIE_Comb_Fungal					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,24), null, "beeComb");
		IL.BINNIE_Comb_Tar						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,25), null, "beeComb");
		IL.BINNIE_Comb_Latex					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,26), null, "beeComb");
		IL.BINNIE_Comb_Brimstone				.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,27), null, "beeComb");
		IL.BINNIE_Comb_Venom					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,28), null, "beeComb");
		IL.BINNIE_Comb_Mucous					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,29), null, "beeComb");
		IL.BINNIE_Comb_Blaze					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,30), null, "beeComb");
		IL.BINNIE_Comb_Coffee					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,31), null, "beeComb");
		IL.BINNIE_Comb_Glacial					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,32), null, "beeComb");
		IL.BINNIE_Comb_Mint						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,33), null, "beeComb");
		IL.BINNIE_Comb_Citrus					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,34), null, "beeComb");
		IL.BINNIE_Comb_Peat						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,35), null, "beeComb");
		IL.BINNIE_Comb_Shadow					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,36), null, "beeComb");
		IL.BINNIE_Comb_Lead						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,37), null, "beeComb");
		IL.BINNIE_Comb_Brass					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,38), null, "beeComb");
		IL.BINNIE_Comb_Electrum					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,39), null, "beeComb");
		IL.BINNIE_Comb_Zinc						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,40), null, "beeComb");
		IL.BINNIE_Comb_Titanium					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,41), null, "beeComb");
		IL.BINNIE_Comb_Tungsten					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,42), null, "beeComb");
		IL.BINNIE_Comb_Steel					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,43), null, "beeComb");
		IL.BINNIE_Comb_Iridium					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,44), null, "beeComb");
		IL.BINNIE_Comb_Platinum					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,45), null, "beeComb");
		IL.BINNIE_Comb_Lapis					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,46), null, "beeComb");
		IL.BINNIE_Comb_Sodalite					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,47), null, "beeComb");
		IL.BINNIE_Comb_Pyrite					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,48), null, "beeComb");
		IL.BINNIE_Comb_Bauxite					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,49), null, "beeComb");
		IL.BINNIE_Comb_Cinnabar					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,50), null, "beeComb");
		IL.BINNIE_Comb_Sphalerite				.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,51), null, "beeComb");
		IL.BINNIE_Comb_Emerald					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,52), null, "beeComb");
		IL.BINNIE_Comb_Ruby						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,53), null, "beeComb");
		IL.BINNIE_Comb_Sapphire					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,54), null, "beeComb");
		IL.BINNIE_Comb_Olivine					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,55), null, "beeComb");
		IL.BINNIE_Comb_Diamond					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,56), null, "beeComb");
		IL.BINNIE_Comb_Red						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,57), null, "beeComb");
		IL.BINNIE_Comb_Yellow					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,58), null, "beeComb");
		IL.BINNIE_Comb_Blue						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,59), null, "beeComb");
		IL.BINNIE_Comb_Green					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,60), null, "beeComb");
		IL.BINNIE_Comb_Black					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,61), null, "beeComb");
		IL.BINNIE_Comb_White					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,62), null, "beeComb");
		IL.BINNIE_Comb_Brown					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,63), null, "beeComb");
		IL.BINNIE_Comb_Orange					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,64), null, "beeComb");
		IL.BINNIE_Comb_Cyan						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,65), null, "beeComb");
		IL.BINNIE_Comb_Purple					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,66), null, "beeComb");
		IL.BINNIE_Comb_Gray						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,67), null, "beeComb");
		IL.BINNIE_Comb_LightBlue				.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,68), null, "beeComb");
		IL.BINNIE_Comb_Pink						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,69), null, "beeComb");
		IL.BINNIE_Comb_Lime						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,70), null, "beeComb");
		IL.BINNIE_Comb_Magenta					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,71), null, "beeComb");
		IL.BINNIE_Comb_LightGray				.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,72), null, "beeComb");
		IL.BINNIE_Comb_Nickel					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,73), null, "beeComb");
		IL.BINNIE_Comb_Invar					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,74), null, "beeComb");
		IL.BINNIE_Comb_Glowing					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,75), null, "beeComb");
		IL.BINNIE_Comb_Unstable					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,76), null, "beeComb");
		IL.BINNIE_Comb_Pulp						.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,77), null, "beeComb");
		IL.BINNIE_Comb_Mulch					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,78), null, "beeComb");
		IL.BINNIE_Comb_Decomposed				.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,79), null, "beeComb");
		IL.BINNIE_Comb_Dusty					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,80), null, "beeComb");
		IL.BINNIE_Comb_Certus					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,81), null, "beeComb");
		IL.BINNIE_Comb_Shimmering				.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,82), null, "beeComb");
		IL.BINNIE_Comb_Yellorium				.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,83), null, "beeComb");
		IL.BINNIE_Comb_Cyanite					.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,84), null, "beeComb");
		IL.BINNIE_Comb_Blutonium				.set(UT.Stacks.make(MD.BINNIE_BEE, "honeyComb"							, 1,85), null, "beeComb");
		IL.FR_Pollen_Cluster					.set(UT.Stacks.make(MD.FR, "pollen"										, 1, 0));
		IL.FR_Pollen_Cluster_Crystalline		.set(UT.Stacks.make(MD.FR, "pollen"										, 1, 1));
		IL.FR_Mulch								.set(UT.Stacks.make(MD.FR, "mulch"										, 1, 0));
		IL.FR_Fertilizer						.set(UT.Stacks.make(MD.FR, "fertilizerCompound"							, 1, 0), null, "itemFertilizer");
		IL.FR_Compost							.set(UT.Stacks.make(MD.FR, "fertilizerBio"								, 1, 0));
		IL.FR_Pulsating_Dust					.set(UT.Stacks.make(MD.FR, "craftingMaterial"							, 1, 0), new OreDictItemData(MT.EnderPearl, U));
		IL.FR_Pulsating_Mesh					.set(UT.Stacks.make(MD.FR, "craftingMaterial"							, 1, 1));
		IL.FR_Silk								.set(UT.Stacks.make(MD.FR, "craftingMaterial"							, 1, 2));
		IL.FR_Silk_Woven						.set(UT.Stacks.make(MD.FR, "craftingMaterial"							, 1, 3));
		IL.FR_Dissipation_Capsule				.set(UT.Stacks.make(MD.FR, "craftingMaterial"							, 1, 4));
		IL.FR_Ice_Shard							.set(UT.Stacks.make(MD.FR, "craftingMaterial"							, 1, 5), new OreDictItemData(MT.Ice, U));
		IL.FR_Iodine_Capsule					.set(UT.Stacks.make(MD.FR, "iodineCapsule"								, 1, 0));
		IL.FR_HoneyPot							.set(UT.Stacks.make(MD.FR, "honeyPot"									, 1, 0));
		IL.FR_Ambrosia							.set(UT.Stacks.make(MD.FR, "ambrosia"									, 1, 0), null, "foodAmbrosia");
		IL.FR_TinCapsule						.set(UT.Stacks.make(MD.FR, "canEmpty"									, 1, 0));
		IL.FR_WaxCapsule						.set(UT.Stacks.make(MD.FR, "waxCapsule"									, 1, 0));
		IL.FR_RefractoryCapsule					.set(UT.Stacks.make(MD.FR, "refractoryEmpty"							, 1, 0));
		IL.FR_Honey_Bucket						.set(UT.Stacks.make(MD.FR, "bucketHoney"								, 1, 0), null, "bucketHoney");
		IL.FR_Honey_Can							.set(UT.Stacks.make(MD.FR, "canHoney"									, 1, 0), null, "container1000honey");
		IL.FR_Honey_Capsule						.set(UT.Stacks.make(MD.FR, "waxCapsuleHoney"							, 1, 0), null, "container1000honey");
		IL.FR_Honey_RefractoryCapsule			.set(UT.Stacks.make(MD.FR, "refractoryHoney"							, 1, 0), null, "container1000honey");
		IL.FR_Water_Can							.set(UT.Stacks.make(MD.FR, "canWater"									, 1, 0), null, "container1000water");
		IL.FR_Water_Capsule						.set(UT.Stacks.make(MD.FR, "waxCapsuleWater"							, 1, 0), null, "container1000water");
		IL.FR_Water_RefractoryCapsule			.set(UT.Stacks.make(MD.FR, "refractoryWater"							, 1, 0), null, "container1000water");
		IL.FR_Lava_RefractoryCapsule			.set(UT.Stacks.make(MD.FR, "refractoryLava"								, 1, 0), null, "container1000lava");
		IL.FR_Candle							.set(UT.Stacks.make(MD.FR, "candle"										, 1, 0));
		IL.FR_Bee_Drone							.set(UT.Stacks.make(MD.FR, "beeDroneGE"									, 1, 0));
		IL.FR_Bee_Princess						.set(UT.Stacks.make(MD.FR, "beePrincessGE"								, 1, 0));
		IL.FR_Bee_Queen							.set(UT.Stacks.make(MD.FR, "beeQueenGE"									, 1, 0));
		IL.FR_Tree_Sapling						.set(UT.Stacks.make(MD.FR, "sapling"									, 1, UT.Stacks.make(MD.FR, "saplingGE", 1)));
		IL.FR_Butterfly							.set(UT.Stacks.make(MD.FR, "butterflyGE"								, 1, 0));
		IL.FR_Larvae							.set(UT.Stacks.make(MD.FR, "beeLarvaeGE"								, 1, 0));
		IL.FR_Serum								.set(UT.Stacks.make(MD.FR, "serumGE"									, 1, 0));
		IL.FR_Caterpillar						.set(UT.Stacks.make(MD.FR, "caterpillarGE"								, 1, 0));
		IL.FR_PollenFertile						.set(UT.Stacks.make(MD.FR, "pollenFertile"								, 1, 0));
		IL.FR_Stick								.set(UT.Stacks.make(MD.FR, "oakStick"									, 1, 0));
		IL.FR_Casing_Impregnated				.set(UT.Stacks.make(MD.FR, "impregnatedCasing"							, 1, 0), new OreDictItemData(MT.TECH.AnyWood	, U *64));
		IL.FR_Casing_Sturdy						.set(UT.Stacks.make(MD.FR, "sturdyMachine"								, 1, 0), new OreDictItemData(MT.Bronze			, U * 8));
		IL.FR_Casing_Hardened					.set(UT.Stacks.make(MD.FR, "hardenedMachine"							, 1, 0), new OreDictItemData(MT.Bronze			, U * 8, MT.Diamond, U * 4));
		IL.FR_Chipset_Tin						.set(UT.Stacks.make(MD.FR, "chipsets"									, 1, 0), new OreDictItemData(MT.Sn				, U * 1, MT.Redstone, U * 6));
		IL.FR_Chipset_Bronze					.set(UT.Stacks.make(MD.FR, "chipsets"									, 1, 1), new OreDictItemData(MT.Bronze			, U * 3, MT.Redstone, U * 6));
		IL.FR_Chipset_Iron						.set(UT.Stacks.make(MD.FR, "chipsets"									, 1, 2), new OreDictItemData(MT.TECH.AnyIron	, U * 3, MT.Redstone, U * 6));
		IL.FR_Chipset_Gold						.set(UT.Stacks.make(MD.FR, "chipsets"									, 1, 3), new OreDictItemData(MT.Au				, U * 3, MT.Redstone, U * 6));
		IL.FR_ElectronTube_Copper				.set(UT.Stacks.make(MD.FR, "thermionicTubes"							, 1, 0), new OreDictItemData(MT.Cu				, 5*U/4, MT.Redstone, U/2, MT.Glass, U/8));
		IL.FR_ElectronTube_Tin					.set(UT.Stacks.make(MD.FR, "thermionicTubes"							, 1, 1), new OreDictItemData(MT.Sn				, 5*U/4, MT.Redstone, U/2, MT.Glass, U/8));
		IL.FR_ElectronTube_Bronze				.set(UT.Stacks.make(MD.FR, "thermionicTubes"							, 1, 2), new OreDictItemData(MT.Bronze			, 5*U/4, MT.Redstone, U/2, MT.Glass, U/8));
		IL.FR_ElectronTube_Iron					.set(UT.Stacks.make(MD.FR, "thermionicTubes"							, 1, 3), new OreDictItemData(MT.TECH.AnyIron	, 5*U/4, MT.Redstone, U/2, MT.Glass, U/8));
		IL.FR_ElectronTube_Gold					.set(UT.Stacks.make(MD.FR, "thermionicTubes"							, 1, 4), new OreDictItemData(MT.Au				, 5*U/4, MT.Redstone, U/2, MT.Glass, U/8));
		IL.FR_ElectronTube_Diamond				.set(UT.Stacks.make(MD.FR, "thermionicTubes"							, 1, 5), new OreDictItemData(MT.Diamond			, 5*U/4, MT.Redstone, U/2, MT.Glass, U/8));
		IL.FR_ElectronTube_Obsidian				.set(UT.Stacks.make(MD.FR, "thermionicTubes"							, 1, 6), new OreDictItemData(MT.Obsidian		, 5*U/4, MT.Redstone, U/2, MT.Glass, U/8));
		IL.FR_ElectronTube_Blaze				.set(UT.Stacks.make(MD.FR, "thermionicTubes"							, 1, 7), new OreDictItemData(MT.Blaze			, 5*U/4, MT.Redstone, U/2, MT.Glass, U/8));
		IL.FR_ElectronTube_Rubber				.set(UT.Stacks.make(MD.FR, "thermionicTubes"							, 1, 8), new OreDictItemData(MT.Rubber			, 5*U/4, MT.Redstone, U/2, MT.Glass, U/8));
		IL.FR_ElectronTube_Emerald				.set(UT.Stacks.make(MD.FR, "thermionicTubes"							, 1, 9), new OreDictItemData(MT.Emerald			, 5*U/4, MT.Redstone, U/2, MT.Glass, U/8));
		IL.FR_ElectronTube_Apatite				.set(UT.Stacks.make(MD.FR, "thermionicTubes"							, 1,10), new OreDictItemData(MT.Apatite			, 5*U/4, MT.Redstone, U/2, MT.Glass, U/8));
		IL.FR_ElectronTube_Lapis				.set(UT.Stacks.make(MD.FR, "thermionicTubes"							, 1,11), new OreDictItemData(MT.Lapis			, 5*U/4, MT.Redstone, U/2, MT.Glass, U/8));
		IL.FR_ElectronTube_Ender				.set(UT.Stacks.make(MD.FR, "thermionicTubes"							, 1,12), new OreDictItemData(MT.Endstone		, 5*U/4, MT.EnderEye, U/2, MT.Glass, U/8));
		IL.BINNIE_Dye_Red						.set(UT.Stacks.make(MD.BINNIE_BEE, "misc"								, 1,19), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Red]);
		IL.BINNIE_Dye_Yellow					.set(UT.Stacks.make(MD.BINNIE_BEE, "misc"								, 1,20), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Yellow]);
		IL.BINNIE_Dye_Blue						.set(UT.Stacks.make(MD.BINNIE_BEE, "misc"								, 1,21), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Blue]);
		IL.BINNIE_Dye_Green						.set(UT.Stacks.make(MD.BINNIE_BEE, "misc"								, 1,22), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Green]);
		IL.BINNIE_Dye_White						.set(UT.Stacks.make(MD.BINNIE_BEE, "misc"								, 1,23), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_White]);
		IL.BINNIE_Dye_Black						.set(UT.Stacks.make(MD.BINNIE_BEE, "misc"								, 1,24), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Black]);
		IL.BINNIE_Dye_Brown						.set(UT.Stacks.make(MD.BINNIE_BEE, "misc"								, 1,25), null, DYE_OREDICTS_MIXABLE[DYE_INDEX_Brown]);
		
		UT.Stacks.item(MD.BINNIE, "containerGlass", Items.potionitem).setContainerItem(Items.glass_bottle);
		
		IL.Cell_Empty							.set(UT.Stacks.makeIC2("cell"												, 1   ), OP.cell.dat(MT.Empty));
		IL.Cell_Water							.set(UT.Stacks.makeIC2("waterCell"											, 1   ), OP.cell.dat(MT.Water));
		IL.Cell_Lava							.set(UT.Stacks.makeIC2("lavaCell"											, 1   ), OP.cell.dat(MT.Lava));
		IL.Cell_Air								.set(UT.Stacks.makeIC2("airCell"											, 1   ), OP.cell.dat(MT.Air));
		OP.cell.mContainerItem =					 UT.Stacks.makeIC2("cell"												, 1   , OreDictManager.INSTANCE.getFirstOre("cellEmpty", 1));
		
		if (MD.IC2C.mLoaded) {
		IL.IC2_Energium_Dust					.set(NI);
		IL.IC2_Fuel_Rod_Empty					.set(NI);
		IL.IC2_Biochaff							.set(UT.Stacks.makeIC2("plantBall"											, 1   ));
		IL.IC2_ShaftIron						.set(NI);
		IL.IC2_ShaftSteel						.set(NI);
		IL.IC2_ForgeHammer						.set(NI);
		IL.IC2_Debug							.set(NI);
		IL.IC2_AdvBattery						.set(NI);
		IL.Cell_Universal_Fluid					.set(NI);
		IL.Cell_UUM								.set(NI);
		IL.Cell_CFoam							.set(NI);
		} else {
		IL.IC2_Energium_Dust					.set(UT.Stacks.makeIC2("energiumDust"										, 1   ));
		IL.IC2_Fuel_Rod_Empty					.set(UT.Stacks.makeIC2("fuelRod"											, 1   ), new OreDictItemData(MT.Fe, U));
		IL.IC2_Biochaff							.set(UT.Stacks.makeIC2("biochaff"											, 1   ));
		IL.IC2_ShaftIron						.set(UT.Stacks.makeIC2("ironshaft"											, 1   ), new OreDictItemData(MT.Fe, U*9));
		IL.IC2_ShaftSteel						.set(UT.Stacks.makeIC2("steelshaft"											, 1   ), new OreDictItemData(MT.Steel, U*9));
		IL.IC2_ForgeHammer						.set(UT.Stacks.makeIC2("ForgeHammer"										, 1   ));
		IL.IC2_Debug							.set(UT.Stacks.makeIC2("debug"												, 1   ));
		IL.IC2_AdvBattery						.set(UT.Stacks.makeIC2("advBattery"											, 1   ));
		IL.Cell_Universal_Fluid					.set(UT.Stacks.makeIC2("FluidCell"											, 1   ), new OreDictItemData(MT.Sn, U*2, OM.stack(MT.Glass, (U * 3)/ 8)));
		IL.Cell_UUM								.set(UT.Stacks.makeIC2("uuMatterCell"										, 1   ), OP.cell.dat(MT.UUMatter));
		IL.Cell_CFoam							.set(UT.Stacks.makeIC2("CFCell"												, 1   ), OP.cell.dat(MT.ConstructionFoam));
		}
		
		IL.IC2_Scaffold							.set(UT.Stacks.makeIC2("scaffold"											, 1   ), new OreDictItemData(MT.Wood, 9*U/8));
		IL.IC2_Scaffold_Iron					.set(UT.Stacks.makeIC2("ironScaffold"										, 1   ), new OreDictItemData(MT.Fe, 15*U/32));
		IL.IC2_Foam								.set(UT.Stacks.makeIC2("constructionFoam"									, 1   ));
		IL.IC2_Foam_Reinforced					.set(UT.Stacks.makeIC2("constructionreinforcedFoam"							, 1   ));
		IL.IC2_Wall								.set(UT.Stacks.makeIC2("constructionFoamWall"								, 1   ));
		IL.IC2_Wall_Reinforced					.set(UT.Stacks.makeIC2("reinforcedStone"									, 1   ));
		IL.IC2_Spray_WeedEx						.set(UT.Stacks.makeIC2("weedEx"												, 1   ), new OreDictItemData(MT.Sn, U, MT.Redstone, U));
		IL.IC2_Mixed_Metal_Ingot				.set(UT.Stacks.makeIC2("mixedMetalIngot"									, 1   ));
		IL.IC2_Fertilizer						.set(UT.Stacks.makeIC2("fertilizer"											, 1   ), null, "itemFertilizer");
		IL.IC2_Resin							.set(UT.Stacks.makeIC2("resin"												, 1   ), null, "itemResin");
		IL.IC2_Log_Rubber						.set(UT.Stacks.makeIC2("rubberWood"											, 1   ));
		IL.IC2_Leaves_Rubber					.set(UT.Stacks.makeIC2("rubberLeaves"										, 1   ));
		IL.IC2_Sapling_Rubber					.set(UT.Stacks.makeIC2("rubberSapling"										, 1   ));
		IL.IC2_Plantball						.set(UT.Stacks.makeIC2("plantBall"											, 1   ));
		IL.IC2_Crop_Seeds						.set(UT.Stacks.makeIC2("cropSeed"											, 1   ));
		IL.IC2_Grin_Powder						.set(UT.Stacks.makeIC2("grinPowder"											, 1   ));
		IL.IC2_Scrap							.set(UT.Stacks.makeIC2("scrap"												, 1   ));
		IL.IC2_Scrapbox							.set(UT.Stacks.makeIC2("scrapBox"											, 1   ));
		IL.IC2_Food_Can_Empty					.set(UT.Stacks.makeIC2("tinCan"												, 1   ), new OreDictItemData(MT.Sn, U/2));
		IL.IC2_Food_Can_Filled					.set(UT.Stacks.makeIC2("filledTinCan"										, 1, 0));
		IL.IC2_Food_Can_Spoiled					.set(UT.Stacks.makeIC2("filledTinCan"										, 1, 1));
		IL.IC2_Food_Can_Poisonous				.set(UT.Stacks.makeIC2("filledTinCan"										, 1, 2));
		IL.IC2_Food_Can_Salmonella				.set(UT.Stacks.makeIC2("filledTinCan"										, 1, 3));
		IL.IC2_Industrial_Diamond				.set(UT.Stacks.makeIC2("industrialDiamond"									, 1, 0), OP.gem.dat(MT.TECH.DiamondIndustrial));
		IL.IC2_Coal_Ball						.set(UT.Stacks.makeIC2("coalBall"											, 1   ), new OreDictItemData(MT.Coal, U*8));
		IL.IC2_Compressed_Coal_Ball				.set(UT.Stacks.makeIC2("compressedCoalBall"									, 1   ), new OreDictItemData(MT.Coal, U*8));
		IL.IC2_Compressed_Coal_Chunk			.set(UT.Stacks.makeIC2("coalChunk"											, 1   ), new OreDictItemData(MT.Coal, U*64, MT.Obsidian, U*9));
		IL.IC2_Carbon_Fiber						.set(UT.Stacks.makeIC2("carbonFiber"										, 1   ));
		IL.IC2_Carbon_Mesh						.set(UT.Stacks.makeIC2("carbonMesh"											, 1   ));
		IL.IC2_Carbon_Plate						.set(UT.Stacks.makeIC2("carbonPlate"										, 1   ));
		IL.IC2_Advanced_Alloy					.set(UT.Stacks.makeIC2("advancedAlloy"										, 1   ));
		IL.IC2_Iridium_Alloy					.set(UT.Stacks.makeIC2("iridiumPlate"										, 1   ), new OreDictItemData(MT.Ir, U*4, MT.Diamond, U*1));
		IL.IC2_Machine							.set(UT.Stacks.makeIC2("machine"											, 1   ), new OreDictItemData(MT.Fe, U*8));
		IL.IC2_Machine_Adv						.set(UT.Stacks.makeIC2("advancedMachine"									, 1   ), new OreDictItemData(MT.Fe, U*8));
		IL.IC2_Generator						.set(UT.Stacks.makeIC2("generator"											, 1   ), new OreDictItemData(MT.Fe, U*8));
		
		IL.IC2_SuBattery						.set(UT.Stacks.makeIC2("suBattery"											, 1   ));
		IL.IC2_ReBattery						.set(UT.Stacks.makeIC2("reBattery"											, 1   ));
		IL.IC2_EnergyCrystal					.set(UT.Stacks.makeIC2("energyCrystal"										, 1   ));
		IL.IC2_LapotronCrystal					.set(UT.Stacks.makeIC2("lapotronCrystal"									, 1   ));
		
		IL.Tool_Sword_Bronze					.set(UT.Stacks.makeIC2("bronzeSword"										, 1   ));
		IL.Tool_Pickaxe_Bronze					.set(UT.Stacks.makeIC2("bronzePickaxe"										, 1   ));
		IL.Tool_Shovel_Bronze					.set(UT.Stacks.makeIC2("bronzeShovel"										, 1   ));
		IL.Tool_Axe_Bronze						.set(UT.Stacks.makeIC2("bronzeAxe"											, 1   ));
		IL.Tool_Hoe_Bronze						.set(UT.Stacks.makeIC2("bronzeHoe"											, 1   ));
		IL.IC2_WireCutter						.set(UT.Stacks.makeIC2("cutter"												, 1   ));
		
		IL.Credit_Iron							.set(UT.Stacks.makeIC2("coin"												, 1   ));
		
		IL.Upgrade_Overclocker					.set(UT.Stacks.makeIC2("overclockerUpgrade"									, 1   ));
		IL.Upgrade_Battery						.set(UT.Stacks.makeIC2("energyStorageUpgrade"								, 1   ));
		
		ArmorsGT.HAZMATS_FROST					.add(UT.Stacks.makeIC2("hazmatHelmet"										, 1, W));
		ArmorsGT.HAZMATS_FROST					.add(UT.Stacks.makeIC2("hazmatChestplate"									, 1, W));
		ArmorsGT.HAZMATS_FROST					.add(UT.Stacks.makeIC2("hazmatLeggings"										, 1, W));
		ArmorsGT.HAZMATS_FROST					.add(UT.Stacks.makeIC2("hazmatBoots"										, 1, W));
		ArmorsGT.HAZMATS_FROST					.add(UT.Stacks.make(MD.TF, "item.arcticHelm"								, 1, W));
		ArmorsGT.HAZMATS_FROST					.add(UT.Stacks.make(MD.TF, "item.arcticPlate"								, 1, W));
		ArmorsGT.HAZMATS_FROST					.add(UT.Stacks.make(MD.TF, "item.arcticLegs"								, 1, W));
		ArmorsGT.HAZMATS_FROST					.add(UT.Stacks.make(MD.TF, "item.arcticBoots"								, 1, W));
		ArmorsGT.HAZMATS_FROST					.add(UT.Stacks.make(MD.TF, "item.yetiHelm"									, 1, W));
		ArmorsGT.HAZMATS_FROST					.add(UT.Stacks.make(MD.TF, "item.yetiPlate"									, 1, W));
		ArmorsGT.HAZMATS_FROST					.add(UT.Stacks.make(MD.TF, "item.yetiLegs"									, 1, W));
		ArmorsGT.HAZMATS_FROST					.add(UT.Stacks.make(MD.TF, "item.yetiBoots"									, 1, W));
		
		ArmorsGT.HAZMATS_HEAT					.add(UT.Stacks.makeIC2("hazmatHelmet"										, 1, W));
		ArmorsGT.HAZMATS_HEAT					.add(UT.Stacks.makeIC2("hazmatChestplate"									, 1, W));
		ArmorsGT.HAZMATS_HEAT					.add(UT.Stacks.makeIC2("hazmatLeggings"										, 1, W));
		ArmorsGT.HAZMATS_HEAT					.add(UT.Stacks.makeIC2("hazmatBoots"										, 1, W));
		
		ArmorsGT.HAZMATS_INSECTS				.add(UT.Stacks.makeIC2("hazmatHelmet"										, 1, W));
		ArmorsGT.HAZMATS_INSECTS				.add(UT.Stacks.makeIC2("hazmatChestplate"									, 1, W));
		ArmorsGT.HAZMATS_INSECTS				.add(UT.Stacks.makeIC2("hazmatLeggings"										, 1, W));
		ArmorsGT.HAZMATS_INSECTS				.add(UT.Stacks.makeIC2("hazmatBoots"										, 1, W));
		ArmorsGT.HAZMATS_INSECTS				.add(UT.Stacks.make(MD.FR, "apiaristHelmet"									, 1, W));
		ArmorsGT.HAZMATS_INSECTS				.add(UT.Stacks.make(MD.FR, "apiaristChest"									, 1, W));
		ArmorsGT.HAZMATS_INSECTS				.add(UT.Stacks.make(MD.FR, "apiaristLegs"									, 1, W));
		ArmorsGT.HAZMATS_INSECTS				.add(UT.Stacks.make(MD.FR, "apiaristBoots"									, 1, W));
		
		ArmorsGT.HAZMATS_BIO					.add(UT.Stacks.makeIC2("hazmatHelmet"										, 1, W));
		ArmorsGT.HAZMATS_BIO					.add(UT.Stacks.makeIC2("hazmatChestplate"									, 1, W));
		ArmorsGT.HAZMATS_BIO					.add(UT.Stacks.makeIC2("hazmatLeggings"										, 1, W));
		ArmorsGT.HAZMATS_BIO					.add(UT.Stacks.makeIC2("hazmatBoots"										, 1, W));
		
		ArmorsGT.HAZMATS_CHEM					.add(UT.Stacks.makeIC2("hazmatHelmet"										, 1, W));
		ArmorsGT.HAZMATS_CHEM					.add(UT.Stacks.makeIC2("hazmatChestplate"									, 1, W));
		ArmorsGT.HAZMATS_CHEM					.add(UT.Stacks.makeIC2("hazmatLeggings"										, 1, W));
		ArmorsGT.HAZMATS_CHEM					.add(UT.Stacks.makeIC2("hazmatBoots"										, 1, W));
		
		ArmorsGT.HAZMATS_GAS					.add(UT.Stacks.makeIC2("hazmatHelmet"										, 1, W));
		ArmorsGT.HAZMATS_GAS					.add(UT.Stacks.makeIC2("hazmatChestplate"									, 1, W));
		ArmorsGT.HAZMATS_GAS					.add(UT.Stacks.makeIC2("hazmatLeggings"										, 1, W));
		ArmorsGT.HAZMATS_GAS					.add(UT.Stacks.makeIC2("hazmatBoots"										, 1, W));
		
		ArmorsGT.HAZMATS_RADIOACTIVE			.add(UT.Stacks.makeIC2("hazmatHelmet"										, 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE			.add(UT.Stacks.makeIC2("hazmatChestplate"									, 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE			.add(UT.Stacks.makeIC2("hazmatLeggings"										, 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE			.add(UT.Stacks.makeIC2("hazmatBoots"										, 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE			.add(UT.Stacks.make(MD.ReC, "reactorcraft_item_hazhelmet"					, 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE			.add(UT.Stacks.make(MD.ReC, "reactorcraft_item_hazchest"					, 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE			.add(UT.Stacks.make(MD.ReC, "reactorcraft_item_hazlegs"						, 1, W));
		ArmorsGT.HAZMATS_RADIOACTIVE			.add(UT.Stacks.make(MD.ReC, "reactorcraft_item_hazboots"					, 1, W));
		
		ArmorsGT.HAZMATS_LIGHTNING				.add(UT.Stacks.makeIC2("hazmatHelmet"										, 1, W));
		ArmorsGT.HAZMATS_LIGHTNING				.add(UT.Stacks.makeIC2("hazmatChestplate"									, 1, W));
		ArmorsGT.HAZMATS_LIGHTNING				.add(UT.Stacks.makeIC2("hazmatLeggings"										, 1, W));
		ArmorsGT.HAZMATS_LIGHTNING				.add(UT.Stacks.makeIC2("hazmatBoots"										, 1, W));
		ArmorsGT.HAZMATS_LIGHTNING				.add(UT.Stacks.make(Items.chainmail_helmet									, 1, W));
		ArmorsGT.HAZMATS_LIGHTNING				.add(UT.Stacks.make(Items.chainmail_chestplate								, 1, W));
		ArmorsGT.HAZMATS_LIGHTNING				.add(UT.Stacks.make(Items.chainmail_leggings								, 1, W));
		ArmorsGT.HAZMATS_LIGHTNING				.add(UT.Stacks.make(Items.chainmail_boots									, 1, W));
	}
}