package gregapi.recipes;

import static gregapi.data.CS.*;
import gregapi.config.ConfigCategories;
import gregapi.data.CS.ConfigsGT;
import gregapi.data.CS.ToolsGT;
import gregapi.data.RM;
import gregapi.item.IItemDamagable;
import gregapi.oredict.OreDictMaterial;
import gregapi.util.OM;
import gregapi.util.UT;
import ic2.api.item.IElectricItem;

import java.util.ArrayList;
import java.util.List;

import net.minecraft.enchantment.Enchantment;
import net.minecraft.entity.EntityLivingBase;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.init.Blocks;
import net.minecraft.item.ItemStack;
import net.minecraft.item.crafting.IRecipe;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.world.World;
import net.minecraftforge.fluids.FluidStack;
import cpw.mods.fml.common.event.FMLInterModComms;

/**
 * @author Gregorius Techneticies
 */
public class GT_ModHandler {
	/**
	 * Adds a Recipe to the Sawmills of GregTech and ThermalCraft
	 */
	public static boolean addSawmillRecipe(ItemStack aInput, ItemStack aOutput1, ItemStack aOutput2) {
		if (UT.Stacks.invalid(aInput) || UT.Stacks.invalid(aOutput1)) return F;
		aOutput1 = OM.get_(aOutput1);
		aOutput2 = OM.get(aOutput2);
		if (!ConfigsGT.RECIPES.get(ConfigCategories.Machines.sawmill, aInput, T)) return F;
	    try {
	    	ThermalExpansion.addSawmillRecipe(1600, aInput, aOutput1, aOutput2, 100);
		} catch(Throwable e) {/*Do nothing*/}
		return T;
	}
	
	/**
	 * Induction Smelter Recipes and Alloy Smelter Recipes
	 */
	public static boolean addAlloySmelterRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, int aDuration, int aEUt, boolean aAllowSecondaryInputEmpty) {
		if (aInput1 == null || (aInput2 == null && !aAllowSecondaryInputEmpty) || UT.Stacks.invalid(aOutput1)) return F;
		aOutput1 = OM.get_(aOutput1);
		boolean temp = F;
		if (addInductionSmelterRecipe(aInput1, aInput2, aOutput1, null, aDuration * aEUt * 2, 0)) temp = T;
		return temp;
	}
	
	/**
	 * Induction Smelter Recipes for TE
	 */
	public static boolean addInductionSmelterRecipe(ItemStack aInput1, ItemStack aInput2, ItemStack aOutput1, ItemStack aOutput2, int aEnergy, int aChance) {
		if (UT.Stacks.invalid(aInput1 == null) || UT.Stacks.invalid(aOutput1)) return F;
		aOutput1 = OM.get_(aOutput1);
		aOutput2 = OM.get(aOutput2);
		if (UT.Stacks.container(aInput1, F) != null || !ConfigsGT.RECIPES.get(ConfigCategories.Machines.inductionsmelter, aInput2==null?aInput1:aOutput1, T)) return F;
	    try {
	    	ThermalExpansion.addSmelterRecipe(aEnergy*10, UT.Stacks.copy(aInput1), aInput2==null?UT.Stacks.make(Blocks.sand, 1, 0):aInput2, aOutput1, aOutput2, aChance);
		} catch(Throwable e) {/*Do nothing*/}
		return T;
	}
	
	/**
	 * Charges an Electric Item. Only if it's a valid Electric Item of course.
	 * This forces the Usage of proper Voltages (so not the transfer limits defined by the Items) unless you ignore the Transfer Limit.
	 * If aTier is Integer.MAX_VALUE it will ignore Tier based Limitations.
	 * @return the actually used Energy.
	 */
	public static int chargeElectricItem(ItemStack aStack, int aCharge, int aTier, boolean aIgnoreLimit, boolean aSimulate) {
		try {
			if (isElectricItem(aStack)) {
				int tTier = ((ic2.api.item.IElectricItem)aStack.getItem()).getTier(aStack);
				if (tTier < 0 || tTier == aTier || aTier == Integer.MAX_VALUE) {
					if (!aIgnoreLimit && tTier >= 0) aCharge = (int)Math.min(aCharge, V[Math.max(0, Math.min(V.length-1, tTier))]);
					if (aCharge > 0) {
						int rCharge = (int)Math.max(0.0, ic2.api.item.ElectricItem.manager.charge(aStack, aCharge, tTier, T, aSimulate));
						return rCharge + (rCharge * 4 > aTier ? aTier : 0);
					}
				}
			}
		} catch (Throwable e) {/*Do nothing*/}
		return 0;
	}
	
	/**
	 * Discharges an Electric Item. Only if it's a valid Electric Item for that of course.
	 * This forces the Usage of proper Voltages (so not the transfer limits defined by the Items) unless you ignore the Transfer Limit.
	 * If aTier is Integer.MAX_VALUE it will ignore Tier based Limitations.
	 * @return the Energy got from the Item.
	 */
	public static int dischargeElectricItem(ItemStack aStack, int aCharge, int aTier, boolean aIgnoreLimit, boolean aSimulate, boolean aIgnoreDischargability) {
		try {
//			if (isElectricItem(aStack) &&  (aIgnoreDischargability || ((ic2.api.item.IElectricItem)aStack.getItem()).canProvideEnergy(aStack))) {
			if (isElectricItem(aStack)) {
				int tTier = ((ic2.api.item.IElectricItem)aStack.getItem()).getTier(aStack);
				if (tTier < 0 || tTier == aTier || aTier == Integer.MAX_VALUE) {
					if (!aIgnoreLimit && tTier >= 0) aCharge = (int)Math.min(aCharge, V[Math.max(0, Math.min(V.length-1, tTier))]);
					if (aCharge > 0) {
//						int rCharge = Math.max(0, ic2.api.item.ElectricItem.manager.discharge(aStack, aCharge + (aCharge * 4 > aTier ? aTier : 0), tTier, T, aSimulate));
						int rCharge = (int)Math.max(0, ic2.api.item.ElectricItem.manager.discharge(aStack, aCharge + (aCharge * 4 > aTier ? aTier : 0), tTier, T, !aIgnoreDischargability, aSimulate));
						return rCharge - (rCharge * 4 > aTier ? aTier : 0);
					}
				}
			}
		} catch (Throwable e) {/*Do nothing*/}
		return 0;
	}
	
	/**
	 * Uses an Electric Item. Only if it's a valid Electric Item for that of course.
	 * @return if the action was successful
	 */
	public static boolean canUseElectricItem(ItemStack aStack, int aCharge) {
		try {
			if (isElectricItem(aStack)) {
				return ic2.api.item.ElectricItem.manager.canUse(aStack, aCharge);
			}
		} catch (Throwable e) {/*Do nothing*/}
		return F;
	}
	
	/**
	 * Uses an Electric Item. Only if it's a valid Electric Item for that of course.
	 * @return if the action was successful
	 */
	public static boolean useElectricItem(ItemStack aStack, int aCharge, EntityPlayer aPlayer) {
		try {
			if (isElectricItem(aStack)) {
				ic2.api.item.ElectricItem.manager.use(aStack, 0, aPlayer);
				if (ic2.api.item.ElectricItem.manager.canUse(aStack, aCharge)) {
					return ic2.api.item.ElectricItem.manager.use(aStack, aCharge, aPlayer);
				}
			}
		} catch (Throwable e) {/*Do nothing*/}
		return F;
	}
	
	/**
	 * Uses an Item. Tries to discharge in case of Electric Items
	 */
	public static boolean damageOrDechargeItem(ItemStack aStack, int aDamage, int aDecharge, EntityLivingBase aPlayer) {
		if (UT.Stacks.invalid(aStack) || (aStack.getMaxStackSize() <= 1 && aStack.stackSize > 1)) return F;
		if (aPlayer != null && aPlayer instanceof EntityPlayer && UT.Entities.hasInfiniteItems(aPlayer)) return T;
		if (aStack.getItem() instanceof IItemDamagable) {
			return ((IItemDamagable)aStack.getItem()).doDamageToItem(aStack, aDamage);
		} else if (GT_ModHandler.isElectricItem(aStack)) {
			if (canUseElectricItem(aStack, aDecharge)) {
				if (aPlayer != null && aPlayer instanceof EntityPlayer) {
					return GT_ModHandler.useElectricItem(aStack, aDecharge, (EntityPlayer)aPlayer);
				}
				return GT_ModHandler.dischargeElectricItem(aStack, aDecharge, Integer.MAX_VALUE, T, F, T) >= aDecharge;
			}
		} else if (aStack.getItem().isDamageable()) {
			if (aPlayer == null) {
				aStack.setItemDamage(aStack.getItemDamage() + aDamage);
			} else {
				aStack.damageItem(aDamage, aPlayer);
			}
			if (aStack.getItemDamage() >= aStack.getMaxDamage()) {
				aStack.setItemDamage(aStack.getMaxDamage()+1);
				ItemStack tStack = UT.Stacks.container(aStack, T);
				if (tStack != null) {
					aStack.func_150996_a(tStack.getItem());
					aStack.setItemDamage(tStack.getItemDamage());
					aStack.stackSize = tStack.stackSize;
					aStack.setTagCompound(tStack.getTagCompound());
				}
			}
			return T;
		}
		return F;
	}
	
	/**
	 * Uses a Soldering Iron
	 */
	public static boolean useSolderingIron(ItemStack aStack, EntityLivingBase aPlayer) {
		if (aPlayer == null || aStack == null) return F;
		if (ToolsGT.contains(TOOL_solderingtool, aStack)) {
			if (aPlayer instanceof EntityPlayer) {
				EntityPlayer tPlayer = (EntityPlayer)aPlayer;
				if (UT.Entities.hasInfiniteItems(tPlayer)) return T;
				for (int i = 0; i < tPlayer.inventory.mainInventory.length; i++) {
					if (ToolsGT.contains(TOOL_solderingmetal, tPlayer.inventory.mainInventory[i])) {
						if (damageOrDechargeItem(aStack, 1, 1000, tPlayer)) {
							if (tPlayer.inventory.mainInventory[i].getItemDamage() >= tPlayer.inventory.mainInventory[i].getMaxDamage()) tPlayer.inventory.mainInventory[i] = null;
						    if (damageOrDechargeItem(tPlayer.inventory.mainInventory[i], 1, 1000, tPlayer)) {
								if (tPlayer.inventory.mainInventory[i].getItemDamage() >= tPlayer.inventory.mainInventory[i].getMaxDamage()) tPlayer.inventory.mainInventory[i] = null;
							    if (tPlayer.inventoryContainer != null) tPlayer.inventoryContainer.detectAndSendChanges();
								return T;
							}
						}
					}
				}
			} else {
				damageOrDechargeItem(aStack, 1, 1000, aPlayer);
				return T;
			}
		}
		return F;
	}
	
	/**
	 * Is this an electric Item, which can charge other Items?
	 */
	public static boolean isChargerItem(ItemStack aStack) {
		try {
			if (isElectricItem(aStack)) {
				return ((ic2.api.item.IElectricItem)aStack.getItem()).canProvideEnergy(aStack);
			}
		} catch (Throwable e) {/*Do nothing*/}
		return F;
	}
	
	/**
	 * Is this an electric Item?
	 */
	public static boolean isElectricItem(ItemStack aStack) {
		try {
			return aStack != null && aStack.getItem() instanceof ic2.api.item.IElectricItem && ((IElectricItem)aStack.getItem()).getTier(aStack) < Integer.MAX_VALUE;
		} catch (Throwable e) {/*Do nothing*/}
		return F;
	}
	
	public static boolean isElectricItem(ItemStack aStack, byte aTier) {
		try {
			return aStack != null && aStack.getItem() instanceof ic2.api.item.IElectricItem && ((IElectricItem)aStack.getItem()).getTier(aStack) == aTier;
		} catch (Throwable e) {/*Do nothing*/}
		return F;
	}
	
	public static boolean isReactorItem(ItemStack aStack) {
		try {
			return aStack != null && aStack.getItem() instanceof ic2.api.reactor.IReactorComponent;
		} catch (Throwable e) {/*Do nothing*/}
		return F;
	}
	
	/**
	 * Copy of the original Helper Class of Thermal Expansion, just to make sure it works even when other Mods include TE-APIs
	 */
	public static class ThermalExpansion {
		public static void addFurnaceRecipe(int energy, ItemStack input, ItemStack output) {
		    NBTTagCompound toSend = new NBTTagCompound();
		    toSend.setInteger("energy", energy);
		    toSend.setTag("input", new NBTTagCompound());
		    toSend.setTag("output", new NBTTagCompound());
		    input.writeToNBT(toSend.getCompoundTag("input"));
		    output.writeToNBT(toSend.getCompoundTag("output"));
		    FMLInterModComms.sendMessage("ThermalExpansion", "FurnaceRecipe", toSend);
	    }
		
	    public static void addPulverizerRecipe(int energy, ItemStack input, ItemStack primaryOutput) {
	        addPulverizerRecipe(energy, input, primaryOutput, null, 0);
	    }
	    
	    public static void addPulverizerRecipe(int energy, ItemStack input, ItemStack primaryOutput, ItemStack secondaryOutput) {
	    	addPulverizerRecipe(energy, input, primaryOutput, secondaryOutput, 100);
	    }
	    
	    public static void addPulverizerRecipe(int energy, ItemStack input, ItemStack primaryOutput, ItemStack secondaryOutput, int secondaryChance) {
	    	if (input == null || primaryOutput == null) return;
	    	NBTTagCompound toSend = new NBTTagCompound();
	        toSend.setInteger("energy", energy);
	        toSend.setTag("input", new NBTTagCompound());
	        toSend.setTag("primaryOutput", new NBTTagCompound());
	        toSend.setTag("secondaryOutput", new NBTTagCompound());
	        input.writeToNBT(toSend.getCompoundTag("input"));
	        primaryOutput.writeToNBT(toSend.getCompoundTag("primaryOutput"));
	        if (secondaryOutput != null) secondaryOutput.writeToNBT(toSend.getCompoundTag("secondaryOutput"));
	        toSend.setInteger("secondaryChance", secondaryChance);
	        FMLInterModComms.sendMessage("ThermalExpansion", "PulverizerRecipe", toSend);
	    }
	    
	    public static void addSawmillRecipe(int energy, ItemStack input, ItemStack primaryOutput) {
	        addSawmillRecipe(energy, input, primaryOutput, null, 0);
	    }
	    
	    public static void addSawmillRecipe(int energy, ItemStack input, ItemStack primaryOutput, ItemStack secondaryOutput) {
	        addSawmillRecipe(energy, input, primaryOutput, secondaryOutput, 100);
	    }
	    
	    public static void addSawmillRecipe(int energy, ItemStack input, ItemStack primaryOutput, ItemStack secondaryOutput, int secondaryChance) {
	    	if (input == null || primaryOutput == null) return;
	    	NBTTagCompound toSend = new NBTTagCompound();
	        toSend.setInteger("energy", energy);
	        toSend.setTag("input", new NBTTagCompound());
	        toSend.setTag("primaryOutput", new NBTTagCompound());
	        toSend.setTag("secondaryOutput", new NBTTagCompound());
	        input.writeToNBT(toSend.getCompoundTag("input"));
	        primaryOutput.writeToNBT(toSend.getCompoundTag("primaryOutput"));
	        if (secondaryOutput != null) secondaryOutput.writeToNBT(toSend.getCompoundTag("secondaryOutput"));
	        toSend.setInteger("secondaryChance", secondaryChance);
	        FMLInterModComms.sendMessage("ThermalExpansion", "SawmillRecipe", toSend);
	    }
	    
	    public static void addSmelterRecipe(int energy, ItemStack primaryInput, ItemStack secondaryInput, ItemStack primaryOutput) {
	        addSmelterRecipe(energy, primaryInput, secondaryInput, primaryOutput, null, 0);
	    }
	    
	    public static void addSmelterRecipe(int energy, ItemStack primaryInput, ItemStack secondaryInput, ItemStack primaryOutput, ItemStack secondaryOutput) {
	        addSmelterRecipe(energy, primaryInput, secondaryInput, primaryOutput, secondaryOutput, 100);
	    }
	    
	    public static void addSmelterRecipe(int energy, ItemStack primaryInput, ItemStack secondaryInput, ItemStack primaryOutput, ItemStack secondaryOutput, int secondaryChance) {
	    	if (primaryInput == null || secondaryInput == null || primaryOutput == null) return;
	    	NBTTagCompound toSend = new NBTTagCompound();
	        toSend.setInteger("energy", energy);
	        toSend.setTag("primaryInput", new NBTTagCompound());
	        toSend.setTag("secondaryInput", new NBTTagCompound());
	        toSend.setTag("primaryOutput", new NBTTagCompound());
	        toSend.setTag("secondaryOutput", new NBTTagCompound());
	        primaryInput.writeToNBT(toSend.getCompoundTag("primaryInput"));
	        secondaryInput.writeToNBT(toSend.getCompoundTag("secondaryInput"));
	        primaryOutput.writeToNBT(toSend.getCompoundTag("primaryOutput"));
	        if (secondaryOutput != null) secondaryOutput.writeToNBT(toSend.getCompoundTag("secondaryOutput"));
	        toSend.setInteger("secondaryChance", secondaryChance);
	        FMLInterModComms.sendMessage("ThermalExpansion", "SmelterRecipe", toSend);
	    }
	    
	    public static void addSmelterBlastOre(OreDictMaterial aMaterial) {
	        NBTTagCompound toSend = new NBTTagCompound();
	        toSend.setString("oreType", aMaterial.toString());
	        FMLInterModComms.sendMessage("ThermalExpansion", "SmelterBlastOreType", toSend);
	    }
	    
	    public static void addCrucibleRecipe(int energy, ItemStack input, FluidStack output) {
	    	if (input == null || output == null) return;
	    	NBTTagCompound toSend = new NBTTagCompound();
	        toSend.setInteger("energy", energy);
	        toSend.setTag("input", new NBTTagCompound());
	        toSend.setTag("output", new NBTTagCompound());
	        input.writeToNBT(toSend.getCompoundTag("input"));
	        output.writeToNBT(toSend.getCompoundTag("output"));
	        FMLInterModComms.sendMessage("ThermalExpansion", "CrucibleRecipe", toSend);
	    }
	    
	    public static void addTransposerFill(int energy, ItemStack input, ItemStack output, FluidStack fluid, boolean reversible) {
	    	if (input == null || output == null || fluid == null) return;
	    	NBTTagCompound toSend = new NBTTagCompound();
	        toSend.setInteger("energy", energy);
	        toSend.setTag("input", new NBTTagCompound());
	        toSend.setTag("output", new NBTTagCompound());
	        toSend.setTag("fluid", new NBTTagCompound());
	        input.writeToNBT(toSend.getCompoundTag("input"));
	        output.writeToNBT(toSend.getCompoundTag("output"));
	        UT.NBT.setBoolean(toSend, "reversible", reversible);
	        fluid.writeToNBT(toSend.getCompoundTag("fluid"));
	        FMLInterModComms.sendMessage("ThermalExpansion", "TransposerFillRecipe", toSend);
	    }
	    
	    public static void addTransposerExtract(int energy, ItemStack input, ItemStack output, FluidStack fluid, int chance, boolean reversible) {
	    	if (input == null || output == null || fluid == null) return;
	    	NBTTagCompound toSend = new NBTTagCompound();
	        toSend.setInteger("energy", energy);
	        toSend.setTag("input", new NBTTagCompound());
	        toSend.setTag("output", new NBTTagCompound());
	        toSend.setTag("fluid", new NBTTagCompound());
	        input.writeToNBT(toSend.getCompoundTag("input"));
	        output.writeToNBT(toSend.getCompoundTag("output"));
	        UT.NBT.setBoolean(toSend, "reversible", reversible);
	        toSend.setInteger("chance", chance);
	        fluid.writeToNBT(toSend.getCompoundTag("fluid"));
	        FMLInterModComms.sendMessage("ThermalExpansion", "TransposerExtractRecipe", toSend);
	    }
	    
	    public static void addMagmaticFuel(String fluidName, int energy) {
	        NBTTagCompound toSend = new NBTTagCompound();
	        toSend.setString("fluidName", fluidName);
	        toSend.setInteger("energy", energy);
	        FMLInterModComms.sendMessage("ThermalExpansion", "MagmaticFuel", toSend);
	    }
	    
	    public static void addCompressionFuel(String fluidName, int energy) {
	        NBTTagCompound toSend = new NBTTagCompound();
	        toSend.setString("fluidName", fluidName);
	        toSend.setInteger("energy", energy);
	        FMLInterModComms.sendMessage("ThermalExpansion", "CompressionFuel", toSend);
	    }
	    
	    public static void addCoolant(String fluidName, int energy) {
	        NBTTagCompound toSend = new NBTTagCompound();
	        toSend.setString("fluidName", fluidName);
	        toSend.setInteger("energy", energy);
	        FMLInterModComms.sendMessage("ThermalExpansion", "Coolant", toSend);
	    }
	}
	
	@Deprecated
	public static class RecipeBits {
		public static long MIRRORED = B[0];
		public static long BUFFERED = B[1];
		public static long KEEPNBT = B[2];
		public static long DISMANTLEABLE = B[3];
		public static long NOT_REMOVABLE = B[4];
		public static long REVERSIBLE = B[5];
		public static long DELETE_ALL_OTHER_RECIPES = B[6];
		public static long DELETE_ALL_OTHER_RECIPES_IF_SAME_NBT = B[7];
		public static long DELETE_ALL_OTHER_SHAPED_RECIPES = B[8];
		public static long DELETE_ALL_OTHER_NATIVE_RECIPES = B[9];
		public static long DO_NOT_CHECK_FOR_COLLISIONS = B[10];
		public static long ONLY_ADD_IF_THERE_IS_ANOTHER_RECIPE_FOR_IT = B[11];
		public static long ONLY_ADD_IF_RESULT_IS_NOT_NULL = B[12];
		public static long DELETE_ONLY_IF_NO_DYE_IS_INVOLVED = B[13];
		public static long NOT_AUTOCRAFTABLE = B[14];
		public static long DEFAULT = BUFFERED|NOT_REMOVABLE;
		public static long DEFAULT_REV = DEFAULT|REVERSIBLE;
		public static long DEFAULT_NCC = DEFAULT|DO_NOT_CHECK_FOR_COLLISIONS;
		public static long DEFAULT_REV_NCC = DEFAULT_REV|DO_NOT_CHECK_FOR_COLLISIONS;
		public static long DEFAULT_NAC = DEFAULT|NOT_AUTOCRAFTABLE;
		public static long DEFAULT_NAC_NCC = DEFAULT_NCC|NOT_AUTOCRAFTABLE;
		public static long DEFAULT_NAC_REV = DEFAULT_REV|NOT_AUTOCRAFTABLE;
		public static long DEFAULT_NAC_REV_NCC = DEFAULT_REV_NCC|NOT_AUTOCRAFTABLE;
	}
	
	@Deprecated public static boolean addCraftingRecipe(ItemStack aResult, Enchantment[] aEnchantmentsAdded, int[] aEnchantmentLevelsAdded, Object[] aRecipe) {return UT.Crafting.shaped(aResult, aEnchantmentsAdded, aEnchantmentLevelsAdded, aRecipe);}
	@Deprecated public static boolean addCraftingRecipe(ItemStack aResult, Object[] aRecipe) {return UT.Crafting.shaped(aResult, UT.Crafting.Bits.DEFAULT, aRecipe);}
	@Deprecated public static boolean addCraftingRecipe(ItemStack aResult, long aBitMask, Object[] aRecipe) {return UT.Crafting.shaped(aResult, aBitMask, aRecipe);}
	@Deprecated public static boolean addShapelessEnchantingRecipe(ItemStack aResult, Enchantment[] aEnchantmentsAdded, int[] aEnchantmentLevelsAdded, Object[] aRecipe) {return UT.Crafting.shapeless(aResult, aEnchantmentsAdded, aEnchantmentLevelsAdded, aRecipe);}
	@Deprecated public static boolean addShapelessCraftingRecipe(ItemStack aResult, Object[] aRecipe) {return UT.Crafting.shapeless(aResult, UT.Crafting.Bits.DEFAULT, aRecipe);}
	@Deprecated public static boolean addShapelessCraftingRecipe(ItemStack aResult, long aBitMask, Object[] aRecipe) {return UT.Crafting.shapeless(aResult, aBitMask, aRecipe);}
	@Deprecated public static ItemStack removeRecipe(ItemStack... aRecipe) {return UT.Crafting.remove(aRecipe);}
	@Deprecated public static boolean removeRecipeByOutput(ItemStack aOutput) {return UT.Crafting.remout(aOutput, T, F, F, F);}
	@Deprecated public static boolean removeRecipeByOutput(ItemStack aOutput, boolean aIgnoreNBT, boolean aNotRemoveShapelessRecipes, boolean aOnlyRemoveNativeHandlers, boolean aDontRemoveDyeingRecipes) {return UT.Crafting.remout(aOutput, aIgnoreNBT, aNotRemoveShapelessRecipes, aOnlyRemoveNativeHandlers, aDontRemoveDyeingRecipes);}
    @Deprecated public static ItemStack getAllRecipeOutput(World aWorld, ItemStack... aRecipe) {return UT.Crafting.getany(aWorld, aRecipe);}
    
    @Deprecated public static ItemStack getRecipeOutput(ItemStack... aRecipe) {return UT.Crafting.get(aRecipe);}
    @Deprecated public static ItemStack getRecipeOutput(boolean aUncopiedStack, ItemStack... aRecipe) {return UT.Crafting.get(aUncopiedStack, aRecipe);}
    @Deprecated public static ArrayList<ItemStack> getRecipeOutputs(ItemStack... aRecipe) {return UT.Crafting.outputs(aRecipe);}
    @Deprecated public static ArrayList<ItemStack> getRecipeOutputs(List<IRecipe> aList, boolean aDeleteFromList, ItemStack... aRecipe) {return UT.Crafting.outputs(aList, aDeleteFromList, aRecipe);}
    
	@Deprecated public static boolean addSmeltingRecipe(ItemStack aInput, ItemStack aOutput) {return RM.add_smelting(aInput, aOutput, 0);}
}