package gregapi.tileentity.energy;

import static gregapi.data.CS.*;
import gregapi.code.TagData;
import gregapi.data.TD;
import gregapi.util.UT;
import ic2.api.energy.EnergyNet;
import ic2.api.energy.tile.IEnergyConductor;
import ic2.api.energy.tile.IEnergySink;
import ic2.api.energy.tile.IEnergySource;
import ic2.api.energy.tile.IEnergyTile;
import net.minecraft.tileentity.TileEntity;
import buildcraft.api.power.ILaserTarget;
import cofh.api.energy.IEnergyConnection;
import cofh.api.energy.IEnergyHandler;
import cofh.api.energy.IEnergyReceiver;

/**
 * @author Gregorius Techneticies
 * 
 * For Internal Use.
 */
public class EnergyCompat {
	public static boolean RF_ENERGY = F, IC_ENERGY = F, BC_LASER = F;
	
	/** Gets Called once during postInit to see which Interfaces are there.*/
	public static void checkAvailabilities() {
		try {
			IEnergyReceiver.class.getCanonicalName();
			IEnergyHandler.class.getCanonicalName();
			IEnergyConnection.class.getCanonicalName();
			RF_ENERGY = T;
		} catch(Throwable e) {/**/}
		try {
			IEnergySink.class.getCanonicalName();
			IEnergySource.class.getCanonicalName();
			IEnergyConductor.class.getCanonicalName();
			IC_ENERGY = T;
		} catch(Throwable e) {/**/}
		try {
			ILaserTarget.class.getCanonicalName();
			BC_LASER = T;
		} catch(Throwable e) {/**/}
	}
	
	public static long insertEnergyInto(TagData aEnergyType, byte aSideInto, long aSize, long aAmount, Object aEmitter, TileEntity aReceiver) {
		long rUsedAmount = 0;
		
		if (aEnergyType == TD.Energy.EU) {
			aSize = Math.abs(aSize);
			if (IC_ENERGY && EnergyNet.instance != null) {
				TileEntity tReceiver = aReceiver instanceof IEnergyTile || EnergyNet.instance == null ? aReceiver : EnergyNet.instance.getTileEntity(aReceiver.getWorldObj(), aReceiver.xCoord, aReceiver.yCoord, aReceiver.zCoord);
				if (tReceiver instanceof IEnergySink && ((IEnergySink)tReceiver).acceptsEnergyFrom(aEmitter instanceof TileEntity ? (TileEntity)aEmitter : null, FORGE_DIR[aSideInto])) {
	    			while (aAmount > rUsedAmount && ((IEnergySink)tReceiver).getDemandedEnergy() >= aSize && ((IEnergySink)tReceiver).injectEnergy(FORGE_DIR[aSideInto], aSize, aSize) < aSize) rUsedAmount++;
	    			return rUsedAmount;
	    		}
			}
		}
		if (RF_ENERGY) {
			long tSizeToReceive = 0;
			// GT KineticUnits auto-convert to RF, but only in the Push Phase, so when they are postive!
			if (aEnergyType == TD.Energy.KU) tSizeToReceive = aSize*RF_PER_EU; else
			// MJ auto-convert to RF too. And yes I do know that BuildCraft and other Mods moved away from MJ to use RF.
			if (aEnergyType == TD.Energy.MJ) tSizeToReceive = aSize*RF_PER_MJ; else
			// RF is RF and therefore doesn't really need to be converted, therefore 1:1 Ratio
			if (aEnergyType == TD.Energy.RF) tSizeToReceive = Math.abs(aSize);
			
			if (tSizeToReceive > 0) {
				if (aReceiver instanceof IEnergyReceiver) {
					if (!(aReceiver instanceof IEnergyConnection) || ((IEnergyConnection)aReceiver).canConnectEnergy(FORGE_DIR[aSideInto])) {
						rUsedAmount += UT.Code.units(((IEnergyReceiver)aReceiver).receiveEnergy(FORGE_DIR[aSideInto], UT.Code.bind31(aAmount * tSizeToReceive), F), tSizeToReceive, 1, T);
						return rUsedAmount;
					}
				}
				if (aReceiver instanceof IEnergyHandler) {
					if (!(aReceiver instanceof IEnergyConnection) || ((IEnergyConnection)aReceiver).canConnectEnergy(FORGE_DIR[aSideInto])) {
						rUsedAmount += UT.Code.units(((IEnergyHandler)aReceiver).receiveEnergy(FORGE_DIR[aSideInto], UT.Code.bind31(aAmount * tSizeToReceive), F), tSizeToReceive, 1, T);
						return rUsedAmount;
					}
				}
			}
		}
		return rUsedAmount;
	}
}